@@ -21,8 +21,8 @@
 FirstRunDialog::FirstRunDialog(TQWidget* parent, const char* name)
  : FirstRunDialogUI(parent, name)
 {
-    connect(key_button, TQT_SIGNAL(capturedShortcut(const TDEShortcut&)),
-        this, TQT_SLOT(validateShortcut(const TDEShortcut&)));
+    connect(key_button, TQ_SIGNAL(capturedShortcut(const TDEShortcut&)),
+        this, TQ_SLOT(validateShortcut(const TDEShortcut&)));
 }
 
 FirstRunDialog::~FirstRunDialog()
