@@ -19,7 +19,7 @@
 
 class GeneralSettings : public GeneralSettingsUI
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
