@@ -30,7 +30,7 @@
 
 class ImageButton : public TranslucentWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
