@@ -27,11 +27,11 @@ TabBar::TabBar(TQWidget* parent, const char* name, bool translucency, const TQSt
 {
     loadSkin(skin);
 
-    connect(plus_button, TQT_SIGNAL(clicked()), this, TQT_SIGNAL(addItem()));
-    connect(minus_button, TQT_SIGNAL(clicked()), this, TQT_SIGNAL(removeItem()));
-    connect(tabs_widget, TQT_SIGNAL(itemSelected(int)), this, TQT_SIGNAL(itemSelected(int)));
-    connect(tabs_widget, TQT_SIGNAL(addItem()), this, TQT_SIGNAL(addItem()));
-    connect(this, TQT_SIGNAL(updateBackground()), this, TQT_SLOT(slotUpdateBackground()));
+    connect(plus_button, TQ_SIGNAL(clicked()), this, TQ_SIGNAL(addItem()));
+    connect(minus_button, TQ_SIGNAL(clicked()), this, TQ_SIGNAL(removeItem()));
+    connect(tabs_widget, TQ_SIGNAL(itemSelected(int)), this, TQ_SIGNAL(itemSelected(int)));
+    connect(tabs_widget, TQ_SIGNAL(addItem()), this, TQ_SIGNAL(addItem()));
+    connect(this, TQ_SIGNAL(updateBackground()), this, TQ_SLOT(slotUpdateBackground()));
 }
 
 TabBar::~TabBar()
@@ -150,18 +150,18 @@ void TabBar::loadSkin(const TQString& skin)
 {
     tabs_widget = new TabbedWidget(this, "Tabbed widget", useTranslucency());
     TQWhatsThis::add(tabs_widget, i18n("The tab bar allows you to switch between sessions."));
-    connect(this, TQT_SIGNAL(updateBackground()), tabs_widget, TQT_SLOT(slotUpdateBackground()));
+    connect(this, TQ_SIGNAL(updateBackground()), tabs_widget, TQ_SLOT(slotUpdateBackground()));
 
     plus_button = new ImageButton(this, "Plus button", useTranslucency());
     plus_button->setDelayedPopup(true);
     TQToolTip::add(plus_button, i18n("New Session"));
     TQWhatsThis::add(plus_button, i18n("Adds a new session. Press and hold to select session type from menu."));
-    connect(this, TQT_SIGNAL(updateBackground()), plus_button, TQT_SLOT(slotUpdateBackground()));
+    connect(this, TQ_SIGNAL(updateBackground()), plus_button, TQ_SLOT(slotUpdateBackground()));
 
     minus_button = new ImageButton(this, "Minus button", useTranslucency());
     TQToolTip::add(minus_button, i18n("Close Session"));
     TQWhatsThis::add(minus_button, i18n("Closes the active session."));
-    connect(this, TQT_SIGNAL(updateBackground()), minus_button, TQT_SLOT(slotUpdateBackground()));
+    connect(this, TQ_SIGNAL(updateBackground()), minus_button, TQ_SLOT(slotUpdateBackground()));
 
     setPixmaps(skin);
 
