@@ -23,7 +23,7 @@ class TerminalSplitter : public TQSplitter
   
 
     public:
-        explicit TerminalSplitter(Qt::Orientation o, TQWidget* parent=0, const char* name=0);
+        explicit TerminalSplitter(TQt::Orientation o, TQWidget* parent=0, const char* name=0);
         ~TerminalSplitter();
 
         void focusNext();
