@@ -22,7 +22,7 @@ class KRootPixmap;
 
 class TranslucentWidget : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
